+++
title = "Under_scores_in_title"
date = 2017-07-28
tags = ["title"]
draft = false
+++

Ensure that the underscores in `title` string of front matter do not
get escaped.. `foo_bar` must not become `foo\_bar`.
